@@ -21,8 +21,8 @@
 // Bound library includes
 #include <QtQuick/qquickframebufferobject.h>
 #include <QtQuick/qquickitem.h>
-#include <QtQuick/qquickitemgrabresult.h>
 #include <QtQuick/qquickpainteditem.h>
+#include <QtQuick/qquickrendertarget.h>
 #include <QtQuick/qquickrhiitem.h>
 #include <QtQuick/qquicktextdocument.h>
 #include <QtQuick/qquickview.h>
@@ -45,10 +45,11 @@ class QQuickGraphicsConfiguration;
 class QQuickGraphicsDevice;
 class QQuickImageProvider;
 class QQuickImageResponse;
+class QQuickItemGrabResult;
 class QQuickRenderControl;
-class QQuickRenderTarget;
 class QQuickRhiItemRenderer;
 class QQuickTextureFactory;
+class QQuickTransform;
 class QSGBasicGeometryNode;
 class QSGClipNode;
 class QSGDynamicTexture;
@@ -70,249 +71,258 @@ QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
-    SBK_QQUICKASYNCIMAGEPROVIDER_IDX                         = 30,
-    SBK_QQUICKFRAMEBUFFEROBJECT_IDX                          = 32,
-    SBK_QQUICKFRAMEBUFFEROBJECT_RENDERER_IDX                 = 34,
-    SBK_QQUICKGRAPHICSCONFIGURATION_IDX                      = 36,
-    SBK_QQUICKGRAPHICSDEVICE_IDX                             = 38,
-    SBK_QQUICKIMAGEPROVIDER_IDX                              = 40,
-    SBK_QQUICKIMAGERESPONSE_IDX                              = 42,
-    SBK_QQUICKITEM_FLAG_IDX                                  = 46,
+    SBK_QQUICKASYNCIMAGEPROVIDER_IDX                         = 32,
+    SBK_QQUICKFRAMEBUFFEROBJECT_IDX                          = 34,
+    SBK_QQUICKFRAMEBUFFEROBJECT_RENDERER_IDX                 = 36,
+    SBK_QQUICKGRAPHICSCONFIGURATION_IDX                      = 38,
+    SBK_QQUICKGRAPHICSDEVICE_IDX                             = 40,
+    SBK_QQUICKIMAGEPROVIDER_IDX                              = 42,
+    SBK_QQUICKIMAGERESPONSE_IDX                              = 44,
+    SBK_QQUICKITEM_FLAG_IDX                                  = 48,
     SBK_QFLAGS_QQUICKITEM_FLAG_IDX                           = 0,
-    SBK_QQUICKITEM_ITEMCHANGE_IDX                            = 48,
-    SBK_QQUICKITEM_TRANSFORMORIGIN_IDX                       = 50,
-    SBK_QQUICKITEM_IDX                                       = 44,
-    SBK_QQUICKITEM_UPDATEPAINTNODEDATA_IDX                   = 52,
-    SBK_QQUICKITEMGRABRESULT_IDX                             = 54,
-    SBK_QQUICKPAINTEDITEM_RENDERTARGET_IDX                   = 60,
-    SBK_QQUICKPAINTEDITEM_PERFORMANCEHINT_IDX                = 58,
+    SBK_QQUICKITEM_ITEMCHANGE_IDX                            = 50,
+    SBK_QQUICKITEM_TRANSFORMORIGIN_IDX                       = 52,
+    SBK_QQUICKITEM_IDX                                       = 46,
+    SBK_QQUICKITEM_UPDATEPAINTNODEDATA_IDX                   = 54,
+    SBK_QQUICKITEMGRABRESULT_IDX                             = 56,
+    SBK_QQUICKPAINTEDITEM_RENDERTARGET_IDX                   = 62,
+    SBK_QQUICKPAINTEDITEM_PERFORMANCEHINT_IDX                = 60,
     SBK_QFLAGS_QQUICKPAINTEDITEM_PERFORMANCEHINT_IDX         = 2,
-    SBK_QQUICKPAINTEDITEM_IDX                                = 56,
-    SBK_QQUICKRENDERCONTROL_IDX                              = 62,
-    SBK_QQUICKRENDERTARGET_IDX                               = 64,
-    SBK_QQUICKRHIITEM_TEXTUREFORMAT_IDX                      = 68,
-    SBK_QQUICKRHIITEM_IDX                                    = 66,
-    SBK_QQUICKRHIITEMRENDERER_IDX                            = 70,
-    SBK_QQUICKTEXTDOCUMENT_STATUS_IDX                        = 74,
-    SBK_QQUICKTEXTDOCUMENT_IDX                               = 72,
-    SBK_QQUICKTEXTUREFACTORY_IDX                             = 76,
-    SBK_QQUICKTRANSFORM_IDX                                  = 78,
-    SBK_QQUICKVIEW_RESIZEMODE_IDX                            = 82,
-    SBK_QQUICKVIEW_STATUS_IDX                                = 84,
-    SBK_QQUICKVIEW_IDX                                       = 80,
-    SBK_QQUICKWINDOW_CREATETEXTUREOPTION_IDX                 = 88,
-    SBK_QFLAGS_QQUICKWINDOW_CREATETEXTUREOPTION_IDX          = 4,
-    SBK_QQUICKWINDOW_RENDERSTAGE_IDX                         = 92,
-    SBK_QQUICKWINDOW_SCENEGRAPHERROR_IDX                     = 94,
-    SBK_QQUICKWINDOW_TEXTRENDERTYPE_IDX                      = 96,
-    SBK_QQUICKWINDOW_IDX                                     = 86,
-    SBK_QQUICKWINDOW_GRAPHICSSTATEINFO_IDX                   = 90,
-    SBK_QSGBASICGEOMETRYNODE_IDX                             = 98,
-    SBK_QSGCLIPNODE_IDX                                      = 100,
-    SBK_QSGDYNAMICTEXTURE_IDX                                = 102,
-    SBK_QSGFLATCOLORMATERIAL_IDX                             = 104,
-    SBK_QSGGEOMETRY_ATTRIBUTETYPE_IDX                        = 112,
-    SBK_QSGGEOMETRY_DATAPATTERN_IDX                          = 116,
-    SBK_QSGGEOMETRY_DRAWINGMODE_IDX                          = 118,
-    SBK_QSGGEOMETRY_TYPE_IDX                                 = 124,
-    SBK_QSGGEOMETRY_IDX                                      = 106,
-    SBK_QSGGEOMETRY_ATTRIBUTE_IDX                            = 108,
-    SBK_QSGGEOMETRY_ATTRIBUTESET_IDX                         = 110,
-    SBK_QSGGEOMETRY_COLOREDPOINT2D_IDX                       = 114,
-    SBK_QSGGEOMETRY_POINT2D_IDX                              = 120,
-    SBK_QSGGEOMETRY_TEXTUREDPOINT2D_IDX                      = 122,
-    SBK_QSGGEOMETRYNODE_IDX                                  = 126,
-    SBK_QSGIMAGENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX     = 130,
-    SBK_QFLAGS_QSGIMAGENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX = 6,
-    SBK_QSGIMAGENODE_IDX                                     = 128,
-    SBK_QSGMATERIAL_FLAG_IDX                                 = 134,
-    SBK_QFLAGS_QSGMATERIAL_FLAG_IDX                          = 8,
-    SBK_QSGMATERIAL_IDX                                      = 132,
-    SBK_QSGMATERIALSHADER_FLAG_IDX                           = 138,
-    SBK_QFLAGS_QSGMATERIALSHADER_FLAG_IDX                    = 10,
-    SBK_QSGMATERIALSHADER_STAGE_IDX                          = 154,
-    SBK_QSGMATERIALSHADER_IDX                                = 136,
-    SBK_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_BLENDFACTOR_IDX = 142,
-    SBK_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_COLORMASKCOMPONENT_IDX = 144,
-    SBK_QFLAGS_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_COLORMASKCOMPONENT_IDX = 12,
-    SBK_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_CULLMODE_IDX = 146,
-    SBK_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_POLYGONMODE_IDX = 148,
-    SBK_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_IDX          = 140,
-    SBK_QSGMATERIALSHADER_RENDERSTATE_DIRTYSTATE_IDX         = 152,
-    SBK_QFLAGS_QSGMATERIALSHADER_RENDERSTATE_DIRTYSTATE_IDX  = 14,
-    SBK_QSGMATERIALSHADER_RENDERSTATE_IDX                    = 150,
-    SBK_QSGMATERIALTYPE_IDX                                  = 156,
-    SBK_QSGNINEPATCHNODE_IDX                                 = 158,
-    SBK_QSGNODE_NODETYPE_IDX                                 = 166,
-    SBK_QSGNODE_FLAG_IDX                                     = 164,
-    SBK_QFLAGS_QSGNODE_FLAG_IDX                              = 18,
-    SBK_QSGNODE_DIRTYSTATEBIT_IDX                            = 162,
-    SBK_QFLAGS_QSGNODE_DIRTYSTATEBIT_IDX                     = 16,
-    SBK_QSGNODE_IDX                                          = 160,
-    SBK_QSGNODEVISITOR_IDX                                   = 168,
-    SBK_QSGOPACITYNODE_IDX                                   = 170,
-    SBK_QSGOPAQUETEXTUREMATERIAL_IDX                         = 172,
-    SBK_QSGRECTANGLENODE_IDX                                 = 174,
-    SBK_QSGRENDERNODE_STATEFLAG_IDX                          = 182,
-    SBK_QFLAGS_QSGRENDERNODE_STATEFLAG_IDX                   = 22,
-    SBK_QSGRENDERNODE_RENDERINGFLAG_IDX                      = 180,
-    SBK_QFLAGS_QSGRENDERNODE_RENDERINGFLAG_IDX               = 20,
-    SBK_QSGRENDERNODE_IDX                                    = 176,
-    SBK_QSGRENDERNODE_RENDERSTATE_IDX                        = 178,
-    SBK_QSGRENDERERINTERFACE_GRAPHICSAPI_IDX                 = 186,
-    SBK_QSGRENDERERINTERFACE_RESOURCE_IDX                    = 190,
-    SBK_QSGRENDERERINTERFACE_SHADERTYPE_IDX                  = 196,
-    SBK_QSGRENDERERINTERFACE_SHADERCOMPILATIONTYPE_IDX       = 192,
-    SBK_QFLAGS_QSGRENDERERINTERFACE_SHADERCOMPILATIONTYPE_IDX = 24,
-    SBK_QSGRENDERERINTERFACE_SHADERSOURCETYPE_IDX            = 194,
-    SBK_QFLAGS_QSGRENDERERINTERFACE_SHADERSOURCETYPE_IDX     = 26,
-    SBK_QSGRENDERERINTERFACE_RENDERMODE_IDX                  = 188,
-    SBK_QSGRENDERERINTERFACE_IDX                             = 184,
-    SBK_QSGROOTNODE_IDX                                      = 198,
-    SBK_QSGSIMPLERECTNODE_IDX                                = 200,
-    SBK_QSGSIMPLETEXTURENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX = 204,
-    SBK_QFLAGS_QSGSIMPLETEXTURENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX = 28,
-    SBK_QSGSIMPLETEXTURENODE_IDX                             = 202,
-    SBK_QSGTEXTNODE_TEXTSTYLE_IDX                            = 210,
-    SBK_QSGTEXTNODE_RENDERTYPE_IDX                           = 208,
-    SBK_QSGTEXTNODE_IDX                                      = 206,
-    SBK_QSGTEXTURE_WRAPMODE_IDX                              = 218,
-    SBK_QSGTEXTURE_FILTERING_IDX                             = 216,
-    SBK_QSGTEXTURE_ANISOTROPYLEVEL_IDX                       = 214,
-    SBK_QSGTEXTURE_IDX                                       = 212,
-    SBK_QSGTEXTUREMATERIAL_IDX                               = 220,
-    SBK_QSGTEXTUREPROVIDER_IDX                               = 222,
-    SBK_QSGTRANSFORMNODE_IDX                                 = 224,
-    SBK_QSGVERTEXCOLORMATERIAL_IDX                           = 226,
-    SBK_QSHAREDPOINTER_QQUICKITEMGRABRESULT_IDX              = 230, // QSharedPointer<QQuickItemGrabResult>
-    SBK_QSHAREDPOINTER_CONSTQQUICKITEMGRABRESULT_IDX         = 230, // (const)
-    SBK_QTQUICK_IDX_COUNT                                    = 232,
+    SBK_QQUICKPAINTEDITEM_IDX                                = 58,
+    SBK_QQUICKRENDERCONTROL_IDX                              = 64,
+    SBK_QQUICKRENDERTARGET_FLAG_IDX                          = 68,
+    SBK_QFLAGS_QQUICKRENDERTARGET_FLAG_IDX                   = 4,
+    SBK_QQUICKRENDERTARGET_IDX                               = 66,
+    SBK_QQUICKRHIITEM_TEXTUREFORMAT_IDX                      = 72,
+    SBK_QQUICKRHIITEM_IDX                                    = 70,
+    SBK_QQUICKRHIITEMRENDERER_IDX                            = 74,
+    SBK_QQUICKTEXTDOCUMENT_STATUS_IDX                        = 78,
+    SBK_QQUICKTEXTDOCUMENT_IDX                               = 76,
+    SBK_QQUICKTEXTUREFACTORY_IDX                             = 80,
+    SBK_QQUICKTRANSFORM_IDX                                  = 82,
+    SBK_QQUICKVIEW_RESIZEMODE_IDX                            = 86,
+    SBK_QQUICKVIEW_STATUS_IDX                                = 88,
+    SBK_QQUICKVIEW_IDX                                       = 84,
+    SBK_QQUICKWINDOW_CREATETEXTUREOPTION_IDX                 = 92,
+    SBK_QFLAGS_QQUICKWINDOW_CREATETEXTUREOPTION_IDX          = 6,
+    SBK_QQUICKWINDOW_RENDERSTAGE_IDX                         = 96,
+    SBK_QQUICKWINDOW_SCENEGRAPHERROR_IDX                     = 98,
+    SBK_QQUICKWINDOW_TEXTRENDERTYPE_IDX                      = 100,
+    SBK_QQUICKWINDOW_IDX                                     = 90,
+    SBK_QQUICKWINDOW_GRAPHICSSTATEINFO_IDX                   = 94,
+    SBK_QSGBASICGEOMETRYNODE_IDX                             = 102,
+    SBK_QSGCLIPNODE_IDX                                      = 104,
+    SBK_QSGDYNAMICTEXTURE_IDX                                = 106,
+    SBK_QSGFLATCOLORMATERIAL_IDX                             = 108,
+    SBK_QSGGEOMETRY_ATTRIBUTETYPE_IDX                        = 116,
+    SBK_QSGGEOMETRY_DATAPATTERN_IDX                          = 120,
+    SBK_QSGGEOMETRY_DRAWINGMODE_IDX                          = 122,
+    SBK_QSGGEOMETRY_TYPE_IDX                                 = 128,
+    SBK_QSGGEOMETRY_IDX                                      = 110,
+    SBK_QSGGEOMETRY_ATTRIBUTE_IDX                            = 112,
+    SBK_QSGGEOMETRY_ATTRIBUTESET_IDX                         = 114,
+    SBK_QSGGEOMETRY_COLOREDPOINT2D_IDX                       = 118,
+    SBK_QSGGEOMETRY_POINT2D_IDX                              = 124,
+    SBK_QSGGEOMETRY_TEXTUREDPOINT2D_IDX                      = 126,
+    SBK_QSGGEOMETRYNODE_IDX                                  = 130,
+    SBK_QSGIMAGENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX     = 134,
+    SBK_QFLAGS_QSGIMAGENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX = 8,
+    SBK_QSGIMAGENODE_IDX                                     = 132,
+    SBK_QSGMATERIAL_FLAG_IDX                                 = 138,
+    SBK_QFLAGS_QSGMATERIAL_FLAG_IDX                          = 10,
+    SBK_QSGMATERIAL_IDX                                      = 136,
+    SBK_QSGMATERIALSHADER_FLAG_IDX                           = 142,
+    SBK_QFLAGS_QSGMATERIALSHADER_FLAG_IDX                    = 12,
+    SBK_QSGMATERIALSHADER_STAGE_IDX                          = 160,
+    SBK_QSGMATERIALSHADER_IDX                                = 140,
+    SBK_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_BLENDFACTOR_IDX = 146,
+    SBK_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_BLENDOP_IDX  = 148,
+    SBK_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_COLORMASKCOMPONENT_IDX = 150,
+    SBK_QFLAGS_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_COLORMASKCOMPONENT_IDX = 14,
+    SBK_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_CULLMODE_IDX = 152,
+    SBK_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_POLYGONMODE_IDX = 154,
+    SBK_QSGMATERIALSHADER_GRAPHICSPIPELINESTATE_IDX          = 144,
+    SBK_QSGMATERIALSHADER_RENDERSTATE_DIRTYSTATE_IDX         = 158,
+    SBK_QFLAGS_QSGMATERIALSHADER_RENDERSTATE_DIRTYSTATE_IDX  = 16,
+    SBK_QSGMATERIALSHADER_RENDERSTATE_IDX                    = 156,
+    SBK_QSGMATERIALTYPE_IDX                                  = 162,
+    SBK_QSGNINEPATCHNODE_IDX                                 = 164,
+    SBK_QSGNODE_NODETYPE_IDX                                 = 172,
+    SBK_QSGNODE_FLAG_IDX                                     = 170,
+    SBK_QFLAGS_QSGNODE_FLAG_IDX                              = 20,
+    SBK_QSGNODE_DIRTYSTATEBIT_IDX                            = 168,
+    SBK_QFLAGS_QSGNODE_DIRTYSTATEBIT_IDX                     = 18,
+    SBK_QSGNODE_IDX                                          = 166,
+    SBK_QSGNODEVISITOR_IDX                                   = 174,
+    SBK_QSGOPACITYNODE_IDX                                   = 176,
+    SBK_QSGOPAQUETEXTUREMATERIAL_IDX                         = 178,
+    SBK_QSGRECTANGLENODE_IDX                                 = 180,
+    SBK_QSGRENDERNODE_STATEFLAG_IDX                          = 188,
+    SBK_QFLAGS_QSGRENDERNODE_STATEFLAG_IDX                   = 24,
+    SBK_QSGRENDERNODE_RENDERINGFLAG_IDX                      = 186,
+    SBK_QFLAGS_QSGRENDERNODE_RENDERINGFLAG_IDX               = 22,
+    SBK_QSGRENDERNODE_IDX                                    = 182,
+    SBK_QSGRENDERNODE_RENDERSTATE_IDX                        = 184,
+    SBK_QSGRENDERERINTERFACE_GRAPHICSAPI_IDX                 = 192,
+    SBK_QSGRENDERERINTERFACE_RESOURCE_IDX                    = 196,
+    SBK_QSGRENDERERINTERFACE_SHADERTYPE_IDX                  = 202,
+    SBK_QSGRENDERERINTERFACE_SHADERCOMPILATIONTYPE_IDX       = 198,
+    SBK_QFLAGS_QSGRENDERERINTERFACE_SHADERCOMPILATIONTYPE_IDX = 26,
+    SBK_QSGRENDERERINTERFACE_SHADERSOURCETYPE_IDX            = 200,
+    SBK_QFLAGS_QSGRENDERERINTERFACE_SHADERSOURCETYPE_IDX     = 28,
+    SBK_QSGRENDERERINTERFACE_RENDERMODE_IDX                  = 194,
+    SBK_QSGRENDERERINTERFACE_IDX                             = 190,
+    SBK_QSGROOTNODE_IDX                                      = 204,
+    SBK_QSGSIMPLERECTNODE_IDX                                = 206,
+    SBK_QSGSIMPLETEXTURENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX = 210,
+    SBK_QFLAGS_QSGSIMPLETEXTURENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX = 30,
+    SBK_QSGSIMPLETEXTURENODE_IDX                             = 208,
+    SBK_QSGTEXTNODE_TEXTSTYLE_IDX                            = 216,
+    SBK_QSGTEXTNODE_RENDERTYPE_IDX                           = 214,
+    SBK_QSGTEXTNODE_IDX                                      = 212,
+    SBK_QSGTEXTURE_WRAPMODE_IDX                              = 224,
+    SBK_QSGTEXTURE_FILTERING_IDX                             = 222,
+    SBK_QSGTEXTURE_ANISOTROPYLEVEL_IDX                       = 220,
+    SBK_QSGTEXTURE_IDX                                       = 218,
+    SBK_QSGTEXTUREMATERIAL_IDX                               = 226,
+    SBK_QSGTEXTUREPROVIDER_IDX                               = 228,
+    SBK_QSGTRANSFORMNODE_IDX                                 = 230,
+    SBK_QSGVERTEXCOLORMATERIAL_IDX                           = 232,
+    SBK_QSHAREDPOINTER_QQUICKITEMGRABRESULT_IDX              = 236, // QSharedPointer<QQuickItemGrabResult>
+    SBK_QSHAREDPOINTER_CONSTQQUICKITEMGRABRESULT_IDX         = 236, // (const)
+    SBK_QTQUICK_IDX_COUNT                                    = 238,
 };
 
 // Type indices
 enum : int {
-    SBK_QQuickAsyncImageProvider_IDX                         = 15,
-    SBK_QQuickFramebufferObject_IDX                          = 16,
-    SBK_QQuickFramebufferObject_Renderer_IDX                 = 17,
-    SBK_QQuickGraphicsConfiguration_IDX                      = 18,
-    SBK_QQuickGraphicsDevice_IDX                             = 19,
-    SBK_QQuickImageProvider_IDX                              = 20,
-    SBK_QQuickImageResponse_IDX                              = 21,
-    SBK_QQuickItem_Flag_IDX                                  = 23,
+    SBK_QQuickAsyncImageProvider_IDX                         = 16,
+    SBK_QQuickFramebufferObject_IDX                          = 17,
+    SBK_QQuickFramebufferObject_Renderer_IDX                 = 18,
+    SBK_QQuickGraphicsConfiguration_IDX                      = 19,
+    SBK_QQuickGraphicsDevice_IDX                             = 20,
+    SBK_QQuickImageProvider_IDX                              = 21,
+    SBK_QQuickImageResponse_IDX                              = 22,
+    SBK_QQuickItem_Flag_IDX                                  = 24,
     SBK_QFlags_QQuickItem_Flag_IDX                           = 0,
-    SBK_QQuickItem_ItemChange_IDX                            = 24,
-    SBK_QQuickItem_TransformOrigin_IDX                       = 25,
-    SBK_QQuickItem_IDX                                       = 22,
-    SBK_QQuickItem_UpdatePaintNodeData_IDX                   = 26,
-    SBK_QQuickItemGrabResult_IDX                             = 27,
-    SBK_QQuickPaintedItem_RenderTarget_IDX                   = 30,
-    SBK_QQuickPaintedItem_PerformanceHint_IDX                = 29,
+    SBK_QQuickItem_ItemChange_IDX                            = 25,
+    SBK_QQuickItem_TransformOrigin_IDX                       = 26,
+    SBK_QQuickItem_IDX                                       = 23,
+    SBK_QQuickItem_UpdatePaintNodeData_IDX                   = 27,
+    SBK_QQuickItemGrabResult_IDX                             = 28,
+    SBK_QQuickPaintedItem_RenderTarget_IDX                   = 31,
+    SBK_QQuickPaintedItem_PerformanceHint_IDX                = 30,
     SBK_QFlags_QQuickPaintedItem_PerformanceHint_IDX         = 1,
-    SBK_QQuickPaintedItem_IDX                                = 28,
-    SBK_QQuickRenderControl_IDX                              = 31,
-    SBK_QQuickRenderTarget_IDX                               = 32,
-    SBK_QQuickRhiItem_TextureFormat_IDX                      = 34,
-    SBK_QQuickRhiItem_IDX                                    = 33,
-    SBK_QQuickRhiItemRenderer_IDX                            = 35,
-    SBK_QQuickTextDocument_Status_IDX                        = 37,
-    SBK_QQuickTextDocument_IDX                               = 36,
-    SBK_QQuickTextureFactory_IDX                             = 38,
-    SBK_QQuickTransform_IDX                                  = 39,
-    SBK_QQuickView_ResizeMode_IDX                            = 41,
-    SBK_QQuickView_Status_IDX                                = 42,
-    SBK_QQuickView_IDX                                       = 40,
-    SBK_QQuickWindow_CreateTextureOption_IDX                 = 44,
-    SBK_QFlags_QQuickWindow_CreateTextureOption_IDX          = 2,
-    SBK_QQuickWindow_RenderStage_IDX                         = 46,
-    SBK_QQuickWindow_SceneGraphError_IDX                     = 47,
-    SBK_QQuickWindow_TextRenderType_IDX                      = 48,
-    SBK_QQuickWindow_IDX                                     = 43,
-    SBK_QQuickWindow_GraphicsStateInfo_IDX                   = 45,
-    SBK_QSGBasicGeometryNode_IDX                             = 49,
-    SBK_QSGClipNode_IDX                                      = 50,
-    SBK_QSGDynamicTexture_IDX                                = 51,
-    SBK_QSGFlatColorMaterial_IDX                             = 52,
-    SBK_QSGGeometry_AttributeType_IDX                        = 56,
-    SBK_QSGGeometry_DataPattern_IDX                          = 58,
-    SBK_QSGGeometry_DrawingMode_IDX                          = 59,
-    SBK_QSGGeometry_Type_IDX                                 = 62,
-    SBK_QSGGeometry_IDX                                      = 53,
-    SBK_QSGGeometry_Attribute_IDX                            = 54,
-    SBK_QSGGeometry_AttributeSet_IDX                         = 55,
-    SBK_QSGGeometry_ColoredPoint2D_IDX                       = 57,
-    SBK_QSGGeometry_Point2D_IDX                              = 60,
-    SBK_QSGGeometry_TexturedPoint2D_IDX                      = 61,
-    SBK_QSGGeometryNode_IDX                                  = 63,
-    SBK_QSGImageNode_TextureCoordinatesTransformFlag_IDX     = 65,
-    SBK_QFlags_QSGImageNode_TextureCoordinatesTransformFlag_IDX = 3,
-    SBK_QSGImageNode_IDX                                     = 64,
-    SBK_QSGMaterial_Flag_IDX                                 = 67,
-    SBK_QFlags_QSGMaterial_Flag_IDX                          = 4,
-    SBK_QSGMaterial_IDX                                      = 66,
-    SBK_QSGMaterialShader_Flag_IDX                           = 69,
-    SBK_QFlags_QSGMaterialShader_Flag_IDX                    = 5,
-    SBK_QSGMaterialShader_Stage_IDX                          = 77,
-    SBK_QSGMaterialShader_IDX                                = 68,
-    SBK_QSGMaterialShader_GraphicsPipelineState_BlendFactor_IDX = 71,
-    SBK_QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent_IDX = 72,
-    SBK_QFlags_QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent_IDX = 6,
-    SBK_QSGMaterialShader_GraphicsPipelineState_CullMode_IDX = 73,
-    SBK_QSGMaterialShader_GraphicsPipelineState_PolygonMode_IDX = 74,
-    SBK_QSGMaterialShader_GraphicsPipelineState_IDX          = 70,
-    SBK_QSGMaterialShader_RenderState_DirtyState_IDX         = 76,
-    SBK_QFlags_QSGMaterialShader_RenderState_DirtyState_IDX  = 7,
-    SBK_QSGMaterialShader_RenderState_IDX                    = 75,
-    SBK_QSGMaterialType_IDX                                  = 78,
-    SBK_QSGNinePatchNode_IDX                                 = 79,
-    SBK_QSGNode_NodeType_IDX                                 = 83,
-    SBK_QSGNode_Flag_IDX                                     = 82,
-    SBK_QFlags_QSGNode_Flag_IDX                              = 9,
-    SBK_QSGNode_DirtyStateBit_IDX                            = 81,
-    SBK_QFlags_QSGNode_DirtyStateBit_IDX                     = 8,
-    SBK_QSGNode_IDX                                          = 80,
-    SBK_QSGNodeVisitor_IDX                                   = 84,
-    SBK_QSGOpacityNode_IDX                                   = 85,
-    SBK_QSGOpaqueTextureMaterial_IDX                         = 86,
-    SBK_QSGRectangleNode_IDX                                 = 87,
-    SBK_QSGRenderNode_StateFlag_IDX                          = 91,
-    SBK_QFlags_QSGRenderNode_StateFlag_IDX                   = 11,
-    SBK_QSGRenderNode_RenderingFlag_IDX                      = 90,
-    SBK_QFlags_QSGRenderNode_RenderingFlag_IDX               = 10,
-    SBK_QSGRenderNode_IDX                                    = 88,
-    SBK_QSGRenderNode_RenderState_IDX                        = 89,
-    SBK_QSGRendererInterface_GraphicsApi_IDX                 = 93,
-    SBK_QSGRendererInterface_Resource_IDX                    = 95,
-    SBK_QSGRendererInterface_ShaderType_IDX                  = 98,
-    SBK_QSGRendererInterface_ShaderCompilationType_IDX       = 96,
-    SBK_QFlags_QSGRendererInterface_ShaderCompilationType_IDX = 12,
-    SBK_QSGRendererInterface_ShaderSourceType_IDX            = 97,
-    SBK_QFlags_QSGRendererInterface_ShaderSourceType_IDX     = 13,
-    SBK_QSGRendererInterface_RenderMode_IDX                  = 94,
-    SBK_QSGRendererInterface_IDX                             = 92,
-    SBK_QSGRootNode_IDX                                      = 99,
-    SBK_QSGSimpleRectNode_IDX                                = 100,
-    SBK_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_IDX = 102,
-    SBK_QFlags_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_IDX = 14,
-    SBK_QSGSimpleTextureNode_IDX                             = 101,
-    SBK_QSGTextNode_TextStyle_IDX                            = 105,
-    SBK_QSGTextNode_RenderType_IDX                           = 104,
-    SBK_QSGTextNode_IDX                                      = 103,
-    SBK_QSGTexture_WrapMode_IDX                              = 109,
-    SBK_QSGTexture_Filtering_IDX                             = 108,
-    SBK_QSGTexture_AnisotropyLevel_IDX                       = 107,
-    SBK_QSGTexture_IDX                                       = 106,
-    SBK_QSGTextureMaterial_IDX                               = 110,
-    SBK_QSGTextureProvider_IDX                               = 111,
-    SBK_QSGTransformNode_IDX                                 = 112,
-    SBK_QSGVertexColorMaterial_IDX                           = 113,
-    SBK_QSharedPointer_QQuickItemGrabResult_IDX              = 115, // QSharedPointer<QQuickItemGrabResult>
-    SBK_QSharedPointer_constQQuickItemGrabResult_IDX         = 115, // (const)
-    SBK_QtQuick_IDX_COUNT                                    = 116,
+    SBK_QQuickPaintedItem_IDX                                = 29,
+    SBK_QQuickRenderControl_IDX                              = 32,
+    SBK_QQuickRenderTarget_Flag_IDX                          = 34,
+    SBK_QFlags_QQuickRenderTarget_Flag_IDX                   = 2,
+    SBK_QQuickRenderTarget_IDX                               = 33,
+    SBK_QQuickRhiItem_TextureFormat_IDX                      = 36,
+    SBK_QQuickRhiItem_IDX                                    = 35,
+    SBK_QQuickRhiItemRenderer_IDX                            = 37,
+    SBK_QQuickTextDocument_Status_IDX                        = 39,
+    SBK_QQuickTextDocument_IDX                               = 38,
+    SBK_QQuickTextureFactory_IDX                             = 40,
+    SBK_QQuickTransform_IDX                                  = 41,
+    SBK_QQuickView_ResizeMode_IDX                            = 43,
+    SBK_QQuickView_Status_IDX                                = 44,
+    SBK_QQuickView_IDX                                       = 42,
+    SBK_QQuickWindow_CreateTextureOption_IDX                 = 46,
+    SBK_QFlags_QQuickWindow_CreateTextureOption_IDX          = 3,
+    SBK_QQuickWindow_RenderStage_IDX                         = 48,
+    SBK_QQuickWindow_SceneGraphError_IDX                     = 49,
+    SBK_QQuickWindow_TextRenderType_IDX                      = 50,
+    SBK_QQuickWindow_IDX                                     = 45,
+    SBK_QQuickWindow_GraphicsStateInfo_IDX                   = 47,
+    SBK_QSGBasicGeometryNode_IDX                             = 51,
+    SBK_QSGClipNode_IDX                                      = 52,
+    SBK_QSGDynamicTexture_IDX                                = 53,
+    SBK_QSGFlatColorMaterial_IDX                             = 54,
+    SBK_QSGGeometry_AttributeType_IDX                        = 58,
+    SBK_QSGGeometry_DataPattern_IDX                          = 60,
+    SBK_QSGGeometry_DrawingMode_IDX                          = 61,
+    SBK_QSGGeometry_Type_IDX                                 = 64,
+    SBK_QSGGeometry_IDX                                      = 55,
+    SBK_QSGGeometry_Attribute_IDX                            = 56,
+    SBK_QSGGeometry_AttributeSet_IDX                         = 57,
+    SBK_QSGGeometry_ColoredPoint2D_IDX                       = 59,
+    SBK_QSGGeometry_Point2D_IDX                              = 62,
+    SBK_QSGGeometry_TexturedPoint2D_IDX                      = 63,
+    SBK_QSGGeometryNode_IDX                                  = 65,
+    SBK_QSGImageNode_TextureCoordinatesTransformFlag_IDX     = 67,
+    SBK_QFlags_QSGImageNode_TextureCoordinatesTransformFlag_IDX = 4,
+    SBK_QSGImageNode_IDX                                     = 66,
+    SBK_QSGMaterial_Flag_IDX                                 = 69,
+    SBK_QFlags_QSGMaterial_Flag_IDX                          = 5,
+    SBK_QSGMaterial_IDX                                      = 68,
+    SBK_QSGMaterialShader_Flag_IDX                           = 71,
+    SBK_QFlags_QSGMaterialShader_Flag_IDX                    = 6,
+    SBK_QSGMaterialShader_Stage_IDX                          = 80,
+    SBK_QSGMaterialShader_IDX                                = 70,
+    SBK_QSGMaterialShader_GraphicsPipelineState_BlendFactor_IDX = 73,
+    SBK_QSGMaterialShader_GraphicsPipelineState_BlendOp_IDX  = 74,
+    SBK_QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent_IDX = 75,
+    SBK_QFlags_QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent_IDX = 7,
+    SBK_QSGMaterialShader_GraphicsPipelineState_CullMode_IDX = 76,
+    SBK_QSGMaterialShader_GraphicsPipelineState_PolygonMode_IDX = 77,
+    SBK_QSGMaterialShader_GraphicsPipelineState_IDX          = 72,
+    SBK_QSGMaterialShader_RenderState_DirtyState_IDX         = 79,
+    SBK_QFlags_QSGMaterialShader_RenderState_DirtyState_IDX  = 8,
+    SBK_QSGMaterialShader_RenderState_IDX                    = 78,
+    SBK_QSGMaterialType_IDX                                  = 81,
+    SBK_QSGNinePatchNode_IDX                                 = 82,
+    SBK_QSGNode_NodeType_IDX                                 = 86,
+    SBK_QSGNode_Flag_IDX                                     = 85,
+    SBK_QFlags_QSGNode_Flag_IDX                              = 10,
+    SBK_QSGNode_DirtyStateBit_IDX                            = 84,
+    SBK_QFlags_QSGNode_DirtyStateBit_IDX                     = 9,
+    SBK_QSGNode_IDX                                          = 83,
+    SBK_QSGNodeVisitor_IDX                                   = 87,
+    SBK_QSGOpacityNode_IDX                                   = 88,
+    SBK_QSGOpaqueTextureMaterial_IDX                         = 89,
+    SBK_QSGRectangleNode_IDX                                 = 90,
+    SBK_QSGRenderNode_StateFlag_IDX                          = 94,
+    SBK_QFlags_QSGRenderNode_StateFlag_IDX                   = 12,
+    SBK_QSGRenderNode_RenderingFlag_IDX                      = 93,
+    SBK_QFlags_QSGRenderNode_RenderingFlag_IDX               = 11,
+    SBK_QSGRenderNode_IDX                                    = 91,
+    SBK_QSGRenderNode_RenderState_IDX                        = 92,
+    SBK_QSGRendererInterface_GraphicsApi_IDX                 = 96,
+    SBK_QSGRendererInterface_Resource_IDX                    = 98,
+    SBK_QSGRendererInterface_ShaderType_IDX                  = 101,
+    SBK_QSGRendererInterface_ShaderCompilationType_IDX       = 99,
+    SBK_QFlags_QSGRendererInterface_ShaderCompilationType_IDX = 13,
+    SBK_QSGRendererInterface_ShaderSourceType_IDX            = 100,
+    SBK_QFlags_QSGRendererInterface_ShaderSourceType_IDX     = 14,
+    SBK_QSGRendererInterface_RenderMode_IDX                  = 97,
+    SBK_QSGRendererInterface_IDX                             = 95,
+    SBK_QSGRootNode_IDX                                      = 102,
+    SBK_QSGSimpleRectNode_IDX                                = 103,
+    SBK_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_IDX = 105,
+    SBK_QFlags_QSGSimpleTextureNode_TextureCoordinatesTransformFlag_IDX = 15,
+    SBK_QSGSimpleTextureNode_IDX                             = 104,
+    SBK_QSGTextNode_TextStyle_IDX                            = 108,
+    SBK_QSGTextNode_RenderType_IDX                           = 107,
+    SBK_QSGTextNode_IDX                                      = 106,
+    SBK_QSGTexture_WrapMode_IDX                              = 112,
+    SBK_QSGTexture_Filtering_IDX                             = 111,
+    SBK_QSGTexture_AnisotropyLevel_IDX                       = 110,
+    SBK_QSGTexture_IDX                                       = 109,
+    SBK_QSGTextureMaterial_IDX                               = 113,
+    SBK_QSGTextureProvider_IDX                               = 114,
+    SBK_QSGTransformNode_IDX                                 = 115,
+    SBK_QSGVertexColorMaterial_IDX                           = 116,
+    SBK_QSharedPointer_QQuickItemGrabResult_IDX              = 118, // QSharedPointer<QQuickItemGrabResult>
+    SBK_QSharedPointer_constQQuickItemGrabResult_IDX         = 118, // (const)
+    SBK_QtQuick_IDX_COUNT                                    = 119,
 };
 
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtQuickTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtQuickTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtQuickModuleObject;
 
@@ -373,6 +383,8 @@ template<> inline PyTypeObject *SbkType< ::QQuickPaintedItem::PerformanceHint >(
 template<> inline PyTypeObject *SbkType< ::QFlags<QQuickPaintedItem::PerformanceHint> >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QQuickPaintedItem_PerformanceHint_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQuickPaintedItem >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickPaintedItem_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQuickRenderControl >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderControl_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQuickRenderTarget::Flag >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_Flag_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QFlags<QQuickRenderTarget::Flag> >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QQuickRenderTarget_Flag_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQuickRenderTarget >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRenderTarget_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQuickRhiItem::TextureFormat >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_TextureFormat_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQuickRhiItem >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickRhiItem_IDX]); }
@@ -417,6 +429,7 @@ template<> inline PyTypeObject *SbkType< ::QFlags<QSGMaterialShader::Flag> >() {
 template<> inline PyTypeObject *SbkType< ::QSGMaterialShader::Stage >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_Stage_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSGMaterialShader >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSGMaterialShader::GraphicsPipelineState::BlendFactor >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_GraphicsPipelineState_BlendFactor_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSGMaterialShader::GraphicsPipelineState::BlendOp >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_GraphicsPipelineState_BlendOp_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSGMaterialShader::GraphicsPipelineState::ColorMaskComponent >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QFlags<QSGMaterialShader::GraphicsPipelineState::ColorMaskComponent> >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QSGMaterialShader_GraphicsPipelineState_ColorMaskComponent_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSGMaterialShader::GraphicsPipelineState::CullMode >() { return Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGMaterialShader_GraphicsPipelineState_CullMode_IDX]); }
